/***************************************************************************
 *   Copyright (C) 2006 by Leon Pennington                                 *
 *   leon@leonscape.co.uk                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef APPLYJOB_H
#define APPLYJOB_H

#include <qobject.h>

// Forward declarations
class Feeds;
class KProcess;
class KTempFile;
namespace KIO{ class Job; };

/**
 * This class is the one that actually setups bashpodder and handles the cronjobs.
 */
class ApplyJob : public QObject
{
Q_OBJECT
public:
    /// Constructor
    ApplyJob( QObject *parent, Feeds *feeds, const QString &cfgDir, const QString &dataDir, const QString &interval, const QString &log, int subdirType );
    /// Destructor
    ~ApplyJob();

    /// Starts the processing of the job
    void begin();

signals:
    /// Emitted when a message should be displayed
    void message( const QString& );
    /// Emitted when the job has succeded
    void success();
    /// Emitted when the job failed, and an error message
    void failed( const QString& );

private slots:
    /// Called when the mkdir for configuration has finished
    void slotMkConfigDirFinish( KIO::Job *job );
    /// Called when the mkdir has finished
    void slotMkDataDirFinish( KIO::Job *job );
    /// Called when the crontab returns data
    void slotCronData( KProcess*, char *buffer, int bufLen );
    /// Called when the crontab returns an error
    void slotCronError( KProcess*, char *buffer, int bufLen );
    /// Called when the crontab data finishes
    void slotCronDataFinish( KProcess* );
    /// Called when the crontab replace finishes
    void slotCronReplaceFinish( KProcess* );

    /// Called if there is a timeout
    void slotTimeOut();

private:
    /// Checks the data directory and the goes on to write files
    void dataDir();
    /// Saves the bp.conf file, the bashfile, and checks crontab
    void writeFiles();

    enum { INTER, MKDIR, CRONLIST, CRONREPLACE } m_timeOut;
    QString m_cronData;
    QString m_cronErrStr;
    bool m_cronErr;
    KTempFile *m_pTFile;

    Feeds *m_pFeeds;
    QString m_dataDir;
    QString m_configDir;
    QString m_inter;
    QString m_log;
    int m_subDirType;
};

#endif
