/***************************************************************************
*   Copyright (C) 2006 by Leon Pennington                                 *
*   leon@leonscape.co.uk                                                  *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include "feedcheck.h"
#include "feeds.h"

#include <kmessagebox.h>
#include <klocale.h>
#include <kprocess.h>
#include <kdebug.h>

#include <qfile.h>

FeedCheck::FeedCheck( QObject *parent, const QString &dataDir, const QString &cfgDir, Feeds *feeds, int subDirType ) : QObject( parent, 0 )
{
    m_dataDir = dataDir;
    m_cfgDir = cfgDir;
    m_pFeeds = feeds;
    m_subDirType = subDirType;
    m_cast = 0;
}

void FeedCheck::begin()
{
    if( m_pFeeds->saveFeeds( m_cfgDir, false, true ) )
    {
        KProcess *proc = new KProcess();
        *proc << "kpodder.sh" << "-c" << m_cfgDir << "-s" << "fullList.casts" << "-o" << m_dataDir << "-d" << QString::number( m_subDirType );

        for ( int i = 0; i < proc->args().size(); ++i )
            kdDebug() << proc->args() [ i ] << endl;

        connect( proc, SIGNAL( processExited( KProcess* ) ), SLOT( slotScriptFinish( KProcess* ) ) );
        connect( proc, SIGNAL( receivedStdout( KProcess*, char*, int ) ), SLOT( slotScriptOut( KProcess*, char*, int ) ) );
        connect( proc, SIGNAL( receivedStderr( KProcess*, char*, int ) ), SLOT( slotScriptOut( KProcess*, char*, int ) ) );
        proc->start( KProcess::NotifyOnExit, KProcess::All );
        emit message( i18n( "Started checking..." ) );
    }
    else
        emit finished( false );
}

void FeedCheck::slotScriptOut( KProcess *proc, char *buff, int len )
{
    QString bufStr = QString::fromLatin1( buff, len );
    emit message( bufStr );
    kdDebug() << bufStr << endl;
}

void FeedCheck::slotScriptFinish( KProcess *proc )
{
    if ( proc->normalExit() && proc->exitStatus() == 0 )
        emit finished( true );
    else
        emit finished( false );
}

#include "feedcheck.moc"
