/***************************************************************************
 *   Copyright (C) 2006 by Leon Pennington                                 *
 *   leon@leonscape.co.uk                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "feeddialog.h"
#include "feeditem.h"
#include "interval.h"

#include <qlayout.h>
#include <qlabel.h>
#include <qcheckbox.h>

#include <klineedit.h>
#include <klocale.h>
#include <kpushbutton.h>

FeedDialog::FeedDialog( QWidget *parent, FeedItem *item )
   : KDialogBase( parent, 0, true, i18n( "Feed" ), KDialogBase::Ok|KDialogBase::Cancel, KDialogBase::Ok, true )
{
   m_pItem = item;
   QWidget *main = new QWidget( this );
   setMainWidget( main );

   QVBoxLayout *top = new QVBoxLayout( main, 0, spacingHint() );
   QGridLayout *gl = new QGridLayout( top, 2, 3 );

   gl->addWidget( new QLabel( i18n( "Name:" ), main ), 0, 0 );
   m_pName = new KLineEdit( item->name(), main );
   m_pName->setMinimumWidth( fontMetrics().maxWidth() * 20 );
   gl->addWidget( m_pName, 0, 1 );
   m_pRetName = new QCheckBox( i18n( "Get name from feed" ), main );
   gl->addWidget( m_pRetName, 0, 2 );

   gl->addWidget( new QLabel( i18n( "URL:" ), main ), 1, 0 );
   m_pURL = new KLineEdit( item->url(), main );
   gl->addWidget( m_pURL, 1, 1 );
   m_pDownload = new KPushButton( i18n( "Download Cast List" ), main );
   gl->addWidget( m_pDownload, 1, 2 );

   QHBoxLayout *hl = new QHBoxLayout( top );
   m_pUseGlobal = new QCheckBox( i18n( "Use global checking" ), main );
   m_pUseGlobal->setChecked( item->globalInterval() );
   hl->addWidget( m_pUseGlobal );
   m_pInterval = new Interval( item->interval(), main );
   hl->addWidget( m_pInterval );

   m_pView = new KListView( main );
   m_pView->addColumn( i18n( "Logged" ) );
   m_pView->addColumn( i18n( "Name" ) );
   m_pView->addColumn( i18n( "File" ) );
   top->addWidget( m_pView );

   slotURL( m_pItem->url() );
   slotGlobalChecked( m_pItem->globalInterval() );

   if( m_pItem->isDownloaded() )
      m_pItem->casts( m_pView );

   if( m_pView->childCount() == 0 )
      m_pView->setEnabled( false );
   else
      m_pView->setEnabled( true );

   connect( m_pURL, SIGNAL( textChanged( const QString& ) ), SLOT( slotURL( const QString& ) ) );
   connect( m_pDownload, SIGNAL( clicked() ), SLOT( slotDownload() ) );
   connect( m_pUseGlobal, SIGNAL( toggled( bool ) ), SLOT( slotGlobalChecked( bool ) ) );
}

void FeedDialog::slotOk()
{
   m_pItem->setName( m_pName->text() );
   m_pItem->setURL( m_pURL->text() );
   m_pItem->setGlobalInterval( m_pUseGlobal->isChecked() );
   m_pItem->setInterval( m_pInterval->string() );
   if( m_pView->childCount() > 0 )
      m_pItem->setCasts( m_pView );
   if( m_pRetName->isChecked() )
      m_pItem->getNameFromURL();
   accept();
}

void FeedDialog::slotURL( const QString &url )
{
   if( m_pItem->isDownloaded( url ) )
   {
      m_pDownload->setEnabled( false );

      if( m_pView->childCount() == 0 )
         m_pView->setEnabled( false );
      else
         m_pView->setEnabled( true );
   }
   else
   {
      m_pDownload->setEnabled( true );
      m_pView->setEnabled( false );
   }
}

void FeedDialog::slotDownload()
{
   if( m_pURL->text().isEmpty() )
      return;

   if( m_pRetName->isChecked() )
   {
      m_pItem->getNameFromURL( m_pName->text(), m_pURL->text() );
      m_pName->setText( m_pItem->name() );
   }

   m_pItem->casts( m_pView, m_pURL->text() );

   if( m_pView->childCount() == 0 )
      m_pView->setEnabled( false );
   else
      m_pView->setEnabled( true );

   m_pDownload->setEnabled( false );
}

void FeedDialog::slotGlobalChecked( bool global )
{
    m_pInterval->setEnabled( !global );
}

#include "feeddialog.moc"
