/***************************************************************************
 *   Copyright (C) 2006 by Leon Pennington                                 *
 *   leon@leonscape.co.uk                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef FEEDITEM_H
#define FEEDITEM_H

#include <qvaluevector.h>
#include <klistview.h>

// Forward declaration
class QFile;

/**
 * This class stores all the details for a feed, Its also a KListViewItem,
 * which has a KListView as a parent.
 *
 * This class is also capable of downloading the feed an examining it for
 * what podcasts are available, and the actual name of the feed.
 */
class FeedItem : public KListViewItem
{
public:
   /**
    * Constructor
    * @param parent The KListView parent
    * @param name The name of the feed
    * @param url The url of the feed
    */
   FeedItem( QListView *parent, const QString &name = QString::null, const QString &url = QString::null, bool global = true, const QString &interval = "" );

   /// Sets the name
   void setName( const QString &name );
   /**
    * Gets the name from the feed itself.
    * @param defName The default name to use if theres a problem getting the name
    * @param url This alters where the feed is to get its info from
    */
   void getNameFromURL( const QString &defName = QString::null, const QString &url = QString::null );
   /// returns the name
   QString name() { return text( 0 ); }

   /// Sets the url
   void setURL( const QString &url );
   /// returns the url
   QString url() { return text( 1 ); }

   /// Set whether to use the global interval or its own
   void setGlobalInterval( bool global );
   /// returns whether to use global interval
   bool globalInterval() { return text( 2 ) == "Yes" ? true : false; }

   /// Set the own interval
   void setInterval( const QString &interval );
   /// Returns the interval
   QString interval() { return text( 3 ); }

   /**
    * This actually downloads the feed, and stores the info
    * @param url This alters where to download the feed from.
    */
   void download( const QString &url = QString::null );
   /**
    * Returns whether the feed has been downloaded
    * @param url This alters where the downloaded check is compared too
    */
   bool isDownloaded( const QString &url = QString::null );

   /**
    * This gets the cast from the feed and adds them to the supplied list view
    * @param url This alters where to download the feed from.
    */
   void casts( KListView *view, const QString &url = QString::null );
   /// The takes whats been set and adds sets the log
   void setCasts( KListView *view );

private:
   /// Holds the address of the last download
   QString m_DLurl;
   /// Holds the name already got from the feed
   QString m_DLName;

   /// Processes the file for casts
   void processFile( QFile *file );
   struct Cast
   {
      QString name;
      QString url;
      QString file;
      bool dled;
   };
   /// The actual pod casts
   QValueVector<Cast> m_casts;
};

#endif
