/***************************************************************************
 *   Copyright (C) 2006 by Leon Pennington                                 *
 *   leon@leonscape.co.uk                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef FEEDS_H
#define FEEDS_H

#include <qwidget.h>

// Forward declarations
class QListViewItem;
class KListView;
class KPushButton;
class KConfig;

/**
 * This class handles the feeds
*/
class Feeds : public QWidget
{
Q_OBJECT
public:
   /// Constructor
   Feeds(QWidget *parent = 0, const char *name = 0);

   /// Called to add a new feed
   void addFeed( const QString &url );

   /// Loads the feeds from a bashpodder file
   bool loadFeeds( const QString &fileName );
   /// Loads the feeds from a KConfig
   void loadFeeds( KConfig *config );
   /// Save the feeds to a kpodder/bashpodder file file
   bool saveFeeds( const QString &fullPath, bool bashpodder = false, bool fullList = false );
   /// Save the feeds to a KConfig
   void saveFeeds( KConfig *config );

   /// Return non-global feeds cron strings
   QStringList cronFeeds();

   /// Empties all the feeds from the list
   void clear();

signals:
   /// Emitted when the feeds are altered
   void dataChanged();

private slots:
   /// Called when a feed is selected
   void slotFeedSelect();
   /// Called when a feed is executed
   void slotFeedExec( QListViewItem* item );
   /// Called when the add feed button is pressed
   void slotAddFeed();
   /// Called when the modify feed button is pressed
   void slotModFeed();
   /// Called when the remove feed button is pressed
   void slotRemFeed();

private:
   KListView *m_pFeeds;
   KPushButton *m_pFeedAdd;
   KPushButton *m_pFeedMod;
   KPushButton *m_pFeedRem;
};

#endif
