/***************************************************************************
 *   Copyright (C) 2006 by Leon Pennington                                 *
 *   leon@leonscape.co.uk                                                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef INTERVAL_H
#define INTERVAL_H

#include <qwidget.h>

// Forward declarations
class QComboBox;
class QLabel;
class KLineEdit;
class KTimeWidget;
class KConfig;

/**
 * The interval widget handles setting times to collect podcasts
*/
class Interval : public QWidget
{
Q_OBJECT
public:
   /// Constructor
   Interval( const QString &str = 0, QWidget *parent = 0, const char *name = 0);

   /// Loads the interval from a KConfig
   void loadInterval( KConfig *config, const QString &feed = 0 );
   /// Saves the interval to a Kconfig
   void saveInterval( KConfig *config, const QString &feed = 0 );

   /// Sets the interval to the defaults
   void setAsDefault();

   /// Returns a string containg the interval in  crontab format
   QString cronString();
   /// Returns a string for use in display
   QString string();
   /// Sets the interval from a display string
   void setInterval( const QString &interval );

   /// Converts display strings to cron strings
   static QString convertString( const QString &str );

signals:
   /// Emitted when the feeds are altered
   void dataChanged();

private slots:
   /// Called when the interval type changes
   void slotIntervalType( int item );
   /// Called when the dates line loses focus
   void slotDatesValid();

private:
   QComboBox *m_pIntervalType;
   QLabel *m_pOnLabel;
   QComboBox *m_pDay;
   KLineEdit *m_pDates;
   QLabel *m_pAtLabel;
   KTimeWidget *m_pTime;
};

#include <qvalidator.h>
/**
 * this class is the validator for the dates entered into the interval
 */
class DateLineValid : public QValidator
{
   Q_OBJECT
public:
   /// Constructor
   DateLineValid( QObject *parent = 0 ) : QValidator( parent )
   {}
   ///
   virtual State validate( QString &input, int &pos ) const;
   ///
   virtual void fixup( QString &input ) const;
};

#endif
