/***************************************************************************
*    Copyright (C) 2006 by Leon Pennington                                *
*    leon@leonscape.co.uk                                                 *
*                                                                         *
*    This program is free software; you can redistribute it and/or modify *
*    it under the terms of the GNU General Public License as published by *
*    the Free Software Foundation; either version 2 of the License, or    *
*    (at your option) any later version.                                  *
*                                                                         *
*    This program is distributed in the hope that it will be useful,      *
*    but WITHOUT ANY WARRANTY; without even the implied warranty of       *
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
*    GNU General Public License for more details.                         *
*                                                                         *
*    You should have received a copy of the GNU General Public License    *
*    along with this program; if not, write to the                        *
*    Free Software Foundation, Inc.,                                      *
*    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.            *
***************************************************************************/


#ifndef _KPODDER_H_
#define _KPODDER_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kmainwindow.h>

// Foward Declarations
class ApplyJob;
class FeedCheck;
class Feeds;
class Interval;

class KLineEdit;
class KPushButton;
class KURLCompletion;
class KConfig;
class KComboBox;

/**
 * @short Application Main Window
 */
class KPodder : public KMainWindow
{
    Q_OBJECT
public:
    /// Default Constructor
    KPodder();

    /// Called to add a new feed to the list
    void addFeed( const QString &url );

    /// Checks a url against the log to see if its been downloaded
    bool inLog( const QString &url );
    /// Called when a url should be added to the log
    void addToLog( const QString &url );
    /// Called when a url should be removed from the log
    void remFromLog( const QString &url );

protected:
    /**
     * This method is called when it is time for the app to save its
     * properties for session management purposes.
     */
    void saveProperties( KConfig *config );
    /**
     * This method is called when this app is restored.  The KConfig
     * object points to the session management config file that was saved
     * with @ref saveProperties
     */
    void readProperties( KConfig *config );

    /// Called when the window is about to close, calls the parts queryClose
    bool queryClose();

private slots:
    /// Called when new is selected
    void fileNew();
    /// Called when import config is selected
    void importConfig();
    /// Called when export config is selected
    void exportConfig();
    /// Called when import log is selected
    void importLog();

    /// Called when the toolbar needs configuring
    void optionsConfigureToolbars();
    /// Called to apply new configuration for toolbars
    void applyNewToolbarConfig();

    /// Called when the data dir has changed
    void slotDataDirChanged();
    /// Called when the data dir button is pressed
    void slotDataDir();

    /// Called when the sub directory type has changed
    void slotSubDirTypeChanged();

    /// Called when the check now button is pressed
    void slotCheckNow();
    /// Called when the check is finished
    void slotCheckNowFinish( bool success );

    /// Called when the apply button is pressed
    void slotApply();
    /// Called when the apply job has finished successfully
    void slotApplySuccess();
    /// Called when the apply job has failed
    void slotApplyFailed( const QString &error );
    /// Called when the reset button is pressed
    void slotReset();

    /// Called when the data changes
    void slotDataChanged()
    {
        setModified( true );
    }

private:
    /// Sets up the interface for the window
    void setupWindow();
    /// Sets the actions for the program
    void setupActions();

    /// Loads the options from a config
    void loadOptions( KConfig *config );
    /// Saves the options from a config
    void saveOptions( KConfig *config );

    /// Holds whether the configuration has been modified
    bool m_modified;
    /// set whether the configuration is modified
    void setModified( bool modified );

    /// Holds the apply job
    ApplyJob *m_pApplyJob;
    /// Holds the check now job
    FeedCheck *m_pFeedCheck;

    /// Holds whether the log has been read in
    bool m_logRead;
    /// Holds the contents of the log
    QStringList m_log;
    /// Reads in the log
    void readLog();

    // Widgets and UI elements
    QWidget *m_pMain;
    Feeds *m_pFeeds;
    Interval *m_pInterval;
    KURLCompletion *m_pDirComplete;
    KLineEdit *m_pDataDir;
    KComboBox *m_pSubDirType;
    KPushButton *m_pDataDirButton;
    KPushButton *m_pCheckNow;
    KPushButton *m_pApply;
    KPushButton *m_pReset;
    QString m_cfgDir;
};

#endif // _KPODDER_H_
